/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*                  This file is part of the program                         */
/*        SMV2LP -- Converting SMV to Integer Linear Programs                */
/*                                                                           */
/*    Copyright (C) 2002-2005 Tobias Achterberg                              */
/*                            Thorsten Koch                                  */
/*                            Robi Malik                                     */
/*                                                                           */
/*                  2002-2005 Konrad-Zuse-Zentrum                            */
/*                            fuer Informationstechnik Berlin                */
/*                                                                           */
/*  SMV2LP is distributed under the terms of the ZIB Academic License.       */
/*                                                                           */
/*  You should have received a copy of the ZIB Academic License              */
/*  along with SMV2LP; see the file COPYING.                                 */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* -*-  c-basic-offset: 3 -*- */

#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>

#include "node.h"
#include "constraint.h"
#include "convert.h"


extern int yyparse(void);
extern int yydebug;
extern int yy_flex_debug;


static Node* parse_tree;

void set_parse_tree(Node* pt)
{
   parse_tree = pt;
}

int main(int argc, char* const* argv)
{
   Bool showtree = FALSE;
   CONSTRAINTSET* cset = NULL;
   int maxT = 0;

   const char* usage =
      "usage: %s [-b][-f][-t][-T<maxT>] < <infile> > <outfile>\n";
   
   int    c;
   
   yydebug       = 0;
   yy_flex_debug = 0;

   while((c = getopt(argc, argv, "bftT:")) != -1)
   {
      switch(c)
      {
      case 'b':
         yydebug = 1;
         break;
      case 'f':
         yy_flex_debug = 1;
         break;
      case 't':
	 showtree = TRUE;
	 break;
      case 'T':
         maxT = atoi(optarg);
         break;
      case '?':
         fprintf(stderr, usage, argv[0]);
         exit(0);
      default :
         abort();
      }
   }

   if (yyparse() != 0)
   {
      fprintf(stderr, "*** Parsing error\n");
      exit(1);
   }

   if (showtree)
   {
      printf("\nPARSE TREE:\n\n");
      tree_display(parse_tree);
   }

#ifdef DEBUG
   printf("\nRUNNING OUTPUT:\n\n");
#endif /* DEBUG */

   /* convert parse tree to constraint set */
   cset = convTreeToCSet(parse_tree);

#ifdef DEBUG
   /* display constraint set */
   consDisplayCSet(cset);
   printf("\n%d constraints, %d variables\n", consGetNumConstraints(cset), consGetNumVariables(cset));
#endif /* DEBUG */

   /* output MIP formulation */
   consCSetToLP(cset, maxT, stdout);

   return 0;
}
