/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*                  This file is part of the program                         */
/*        SMV2LP -- Converting SMV to Integer Linear Programs                */
/*                                                                           */
/*    Copyright (C) 2002-2005 Tobias Achterberg                              */
/*                            Thorsten Koch                                  */
/*                            Robi Malik                                     */
/*                                                                           */
/*                  2002-2005 Konrad-Zuse-Zentrum                            */
/*                            fuer Informationstechnik Berlin                */
/*                                                                           */
/*  SMV2LP is distributed under the terms of the ZIB Academic License.       */
/*                                                                           */
/*  You should have received a copy of the ZIB Academic License              */
/*  along with SMV2LP; see the file COPYING.                                 */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: message.h,v 1.19 2005/03/10 17:11:15 bzfpfend Exp $"

/**@file   message.h
 * @brief  message output methods
 * @author Tobias Achterberg
 *
 * Because the message functions are implemented as defines with more than one
 * function call, they shouldn't be used as a single statement like in:
 *   if( error )
 *      errorMessage("an error occured");
 * because this would produce the following macro extension:
 *   if( error )
 *      printf(("[%s:%d] ERROR: ", __FILE__, __LINE__);
 *   printf(("an error occured");
 * Instead, they should be protected with brackets:
 *   if( error )
 *   {
 *      errorMessage("an error occured");
 *   }
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __MESSAGE_H__
#define __MESSAGE_H__



#define errorMessage                    printf("[%s:%d] ERROR: ", __FILE__, __LINE__); printf
#define warningMessage                  printf("[%s:%d] Warning: ", __FILE__, __LINE__); printf

#ifdef DEBUG
#define debug(x)                        x
#define debugMessage                    printf("[%s:%d] debug: ", __FILE__, __LINE__); printf
#else
#define debug(x)                        /**/
#define debugMessage                    while( FALSE ) printf
#endif


#endif

